@@ -1,4 +1,4 @@
-import { allIntelCpus, allowedIntelCpus, configValues, defaultInterfaces,
+import { allIntelCpus, allowedIntelCpus, configValues, defaultInterfaces, filteredNetworkInterfaces,
          resourceConstants, status } from "../../components/HostedEngineSetup/constants"
 
 export class DefaultValueProvider {
@@ -19,7 +19,9 @@ export class DefaultValueProvider {
         this.virtSupported = this.virtSupported.bind(this);
         this.getTimeZone = this.getTimeZone.bind(this);
         this.getNetworkInterfaces = this.getNetworkInterfaces.bind(this);
+        this.getIpAddress = this.getIpAddress.bind(this);
         this.getIpData = this.getIpData.bind(this);
+        this.getFQDN = this.getFQDN.bind(this);
         this.isEmptyObject = this.isEmptyObject.bind(this);
 
         this.getSystemData();
@@ -167,8 +169,9 @@ export class DefaultValueProvider {
         const ansibleInterfaces = this.getTaskData("Gathering Facts")["ansible_facts"]["ansible_interfaces"];
 
         if (typeof ansibleInterfaces !== "undefined" && ansibleInterfaces.length > 0) {
+            const filteredInterfaces = ansibleInterfaces.filter(iface => !filteredNetworkInterfaces.includes(iface));
             const interfacesArray = [];
-            ansibleInterfaces.forEach(function (iface) {
+            filteredInterfaces.forEach(function (iface) {
                 interfacesArray.push({key: iface, title: iface});
             });
 
@@ -195,7 +198,12 @@ export class DefaultValueProvider {
 
     getDefaultGateway() {
         const ipData = this.getIpData();
-        return ipData !== null ? this.getIpData()["gateway"] : "";
+        return ipData !== null ? ipData["gateway"] : "";
+    }
+
+    getIpAddress() {
+        const ipData = this.getIpData();
+        return ipData !== null ? ipData["address"] : "";
     }
 
     getIpData() {
@@ -213,6 +221,15 @@ export class DefaultValueProvider {
         return ipData;
     }
 
+    getFQDN() {
+        const fqdnData = this.getTaskData("Get FQDN");
+        let fqdn = "";
+        if (typeof fqdnData !== "undefined") {
+            fqdn = fqdnData["stdout"];
+        }
+        return fqdn;
+    }
+
     isEmptyObject(obj) {
         return Object.keys(obj).length === 0 && obj.constructor === Object;
     }
